@@ -108,18 +108,6 @@ probe.cor <- function (
   }
 }
 
-probe.marginal <- function (var, ref, order = 3, diff = 1, transform = identity) {
-  if (length(var)>1) stop(sQuote("probe.marginal")," is a univariate probe")
-  transform <- match.fun(transform)
-  setup <- .Call(probe_marginal_setup,transform(ref),order,diff)
-  function (y) .Call(
-                     probe_marginal_solve,
-                     x=transform(y[var,]),
-                     setup=setup,
-                     diff=diff
-                     )
-}
-
 probe.acf <- function (var, lag.max, type = c("covariance", "correlation"), transform = identity) {
   type <- match.arg(type)
   transform <- match.fun(transform)
@@ -131,3 +119,49 @@ probe.acf <- function (var, lag.max, type = c("covariance", "correlation"), tran
                      corr=corr
                      )
 }
+
+probe.ccf <- function (vars, lags, transform = identity) {
+  transform <- match.fun(transform)
+  if (length(vars)!=2)
+    stop(sQuote("vars")," must name two variables")
+  function (y) .Call(
+                     probe_ccf,
+                     x=transform(y[vars[1],,drop=TRUE]),
+                     y=transform(y[vars[2],,drop=TRUE]),
+                     lags=lags
+                     )
+}
+
+probe.marginal <- function (var, ref, order = 3, diff = 1, transform = identity) {
+  if (length(var)>1) stop(sQuote("probe.marginal")," is a univariate probe")
+  transform <- match.fun(transform)
+  setup <- .Call(probe_marginal_setup,transform(ref),order,diff)
+  function (y) .Call(
+                     probe_marginal_solve,
+                     x=transform(y[var,,drop=TRUE]),
+                     setup=setup,
+                     diff=diff
+                     )
+}
+
+probe.nlar <- function (var, lags, powers, transform = identity) {
+  if (length(var)>1) stop(sQuote("probe.nlar")," is a univariate probe")
+  transform <- match.fun(transform)
+  if (any(lags<1)||any(powers<1))
+    stop(sQuote("lags")," and ",sQuote("powers")," must be positive integers")
+  if (length(lags)<length(powers)) {
+    if (length(lags)>1) stop(sQuote("lags")," must match ",sQuote("powers")," in length, or have length 1")
+    lags <- rep(lags,length(powers))
+  } else if (length(lags)>length(powers)) {
+    if (length(powers)>1) stop(sQuote("powers")," must match ",sQuote("lags")," in length, or have length 1")
+    powers <- rep(powers,length(lags))
+  }
+  lags <- as.integer(lags)
+  powers <- as.integer(powers)
+  function (y) .Call(
+                     probe_nlar,
+                     x=transform(y[var,,drop=TRUE]),
+                     lags=lags,
+                     powers=powers
+                     )
+}
